<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>DesktopSwitch</name>
    <message>
        <source>Desktop %1</source>
        <translation>Arbeitsfläche %1</translation>
    </message>
</context>
</TS>